@@ -26,7 +26,7 @@ import Data.GI.Base.GClosure (GClosure)
 import Data.GI.Base.Constructible (new)
 import Data.GI.Base.GError
 import Data.GI.Base.GHashTable
-import Data.GI.Base.GValue (GValue(..), IsGValue(..))
+import Data.GI.Base.GValue (GValue(..), fromGValue, toGValue, IsGValue(..))
 import Data.GI.Base.GVariant
 import Data.GI.Base.ManagedPtr
 import Data.GI.Base.Signals (on, after, SignalProxy(PropertyNotify, (:::)))
